@@ -7,7 +7,9 @@ import logging
 import os
 import socket
 import sys
-from typing import Iterable, Optional
+from typing import (
+    Awaitable, Callable, Iterable, Optional,
+)
 from pathlib import Path
 
 import aiodns
@@ -75,8 +77,6 @@ def detect_cloud() -> Optional[str]:
             # but it requires sudo privilege.
         except IOError:
             pass
-    else:
-        log.warning('Cloud detection is implemented for Linux only yet.')
     return None
 
 
@@ -102,11 +102,11 @@ else:
     log.info(f'Detected environment: {current_provider} cloud')
     log.info('The agent node ID will follow the instance ID.')
 
-_defined = False
-get_instance_id = None
-get_instance_ip = None
-get_instance_type = None
-get_instance_region = None
+_defined: bool = False
+get_instance_id: Callable[[], Awaitable[str]]
+get_instance_ip: Callable[[Optional[BaseIPNetwork]], Awaitable[str]]
+get_instance_type: Callable[[], Awaitable[str]]
+get_instance_region: Callable[[], Awaitable[str]]
 
 
 def _define_functions():
